import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Body1Strong, Button, InfoLabel, makeStyles, tokens } from "@fluentui/react-components";
import { Add24Filled, Copy24Regular, Subtract24Filled } from "@fluentui/react-icons";
import { useContext, useState } from "react";
import { copyCommandToClipboard } from "../../copyCommandToClipboard.js";
import { ToolContext } from "./fluentToolWrapper.js";
const usePropertyLineStyles = makeStyles({
    container: {
        width: "100%",
        display: "flex",
        flexDirection: "column", // Stack line + expanded content
        borderBottom: `${tokens.strokeWidthThin} solid ${tokens.colorNeutralStroke1}`,
    },
    line: {
        display: "flex",
        alignItems: "center",
        justifyContent: "flex-start",
        padding: `${tokens.spacingVerticalXS} 0px`,
        width: "100%",
    },
    label: {
        width: "33%",
        textAlign: "left",
    },
    rightContent: {
        width: "67%",
        display: "flex",
        alignItems: "center",
        justifyContent: "flex-end",
    },
    button: {
        marginLeft: tokens.spacingHorizontalXXS,
        width: "100px",
    },
    fillRestOfRightContentWidth: {
        flex: 1,
        display: "flex",
        justifyContent: "flex-end",
        alignItems: "center",
    },
    expandedContent: {
        backgroundColor: tokens.colorNeutralBackground1,
    },
});
export const LineContainer = (props) => {
    const classes = usePropertyLineStyles();
    return _jsx("div", { className: classes.container, children: props.children });
};
/**
 * A reusable component that renders a property line with a label and child content, and an optional description, copy button, and expandable section.
 *
 * @param props - The properties for the PropertyLine component.
 * @returns A React element representing the property line.
 *
 */
export const PropertyLine = (props) => {
    const classes = usePropertyLineStyles();
    const [expanded, setExpanded] = useState(false);
    const { label, description, onCopy, expandedContent, children } = props;
    const { disableCopy } = useContext(ToolContext);
    return (_jsxs(LineContainer, { children: [_jsxs("div", { className: classes.line, children: [_jsx(InfoLabel, { className: classes.label, info: description, children: _jsx(Body1Strong, { children: label }) }), _jsxs("div", { className: classes.rightContent, children: [_jsx("div", { className: classes.fillRestOfRightContentWidth, children: children }), expandedContent && (_jsx(Button, { appearance: "subtle", icon: expanded ? _jsx(Subtract24Filled, {}) : _jsx(Add24Filled, {}), className: classes.button, onClick: (e) => {
                                    e.stopPropagation();
                                    setExpanded((expanded) => !expanded);
                                } })), onCopy && !disableCopy && (_jsx(Button, { className: classes.button, id: "copyProperty", icon: _jsx(Copy24Regular, {}), onClick: () => copyCommandToClipboard(onCopy()), title: "Copy to clipboard" }))] })] }), expanded && expandedContent && _jsx("div", { className: classes.expandedContent, children: expandedContent })] }));
};
//# sourceMappingURL=propertyLine.js.map