import type { PropertyLineProps } from "./propertyLine.js";
import type { SyncedSliderProps } from "../primitives/syncedSlider.js";
export type SyncedSliderLineProps<O, K> = PropertyLineProps & Omit<SyncedSliderProps, "value" | "onChange"> & {
    /**
     * String key
     */
    propertyKey: K;
    /**
     * target where O[K] is a number
     */
    target: O;
    /**
     * Callback when either the slider or input value changes
     */
    onChange?: (value: number) => void;
};
/**
 * Renders a SyncedSlider within a PropertyLine for a given key/value pair, where the value is number (ex: can be used for a color's RGBA values, a vector's XYZ values, etc)
 * When value changes, updates the object with the new value and calls the onChange callback.
 *
 * Example usage looks like
 *    \<SyncedSliderLine propertyKey="x" target=\{vector\} /\>
 *    \<SyncedSliderLine propertyKey="r" target=\{color\} /\>
 * @param props
 * @returns
 */
export declare const SyncedSliderLine: <O extends Record<K, number>, K extends PropertyKey>(props: SyncedSliderLineProps<O, K>) => React.ReactElement;
