import { jsx as _jsx } from "react/jsx-runtime";
import { PropertyLine } from "./propertyLine.js";
import { SyncedSliderInput } from "../primitives/syncedSlider.js";
/**
 * Renders a SyncedSlider within a PropertyLine for a given key/value pair, where the value is number (ex: can be used for a color's RGBA values, a vector's XYZ values, etc)
 * When value changes, updates the object with the new value and calls the onChange callback.
 *
 * Example usage looks like
 *    \<SyncedSliderLine propertyKey="x" target=\{vector\} /\>
 *    \<SyncedSliderLine propertyKey="r" target=\{color\} /\>
 * @param props
 * @returns
 */
export const SyncedSliderLine = (props) => {
    return (_jsx(PropertyLine, { ...props, children: _jsx(SyncedSliderInput, { ...props, value: props.target[props.propertyKey], onChange: (val) => {
                props.target[props.propertyKey] = val;
                props.onChange?.(val);
            } }) }));
};
//# sourceMappingURL=syncedSliderLine.js.map